# v3.0.0 Upgrade Details

Loki v3.0.0 instituted a new default limit of 15 labels which is a decrease from the previous limit of 30.

This is the explanataion provided by the Grafana team:

> Loki now enforces a max label limit of 15 labels per series, down from 30. Extra labels inflate the size of the index and reduce performance, you should almost never need more than 15 labels.

Updates have been made to fluentbit and promtail to promote staying within this limit and all Big Bang package logs are compliant with it.

However, it is possible that custom configurations may exceed this limit. If you are negatively affected by this change, please review the instructions below to guide you in changing the limit to a more suitable value.

## Instructions
> Note: This is not supported by BigBang as Grafana Labs explictly states this can reduce performance. Increased limits are used at your own risk.

You will need to supply a `limits_config` map in the `loki.values` section of your `values.yaml` file. This map should contain a `max_label_names_per_series` key with the desired limit as an integer value. For example, to set the limit to 30 labels, you would add the following to your Big Bang umbrella chart's `values.yaml` file:

```yaml
loki:
  values:
    limits_config:
      max_label_names_per_series: 25
```

## v13 Schema Upgrade

Loki v3.x adds native support for the Open Telemetry Protocol (OTLP). This is made possible by a new feature in Loki called Structured Metadata, a place for metadata which doesn’t belong in labels or log lines.

Structured Metadata is enabled by default in Loki 3.0, however, it requires your active schema be using both the tsdb index type AND the v13 storage schema. If you are not using both of these you have two options:

* Upgrade your index version and schema version before updating to 3.0, see schema config upgrade.
* Disable Structured Metadata (and therefor OTLP support) and upgrade to 3.0 and perform the schema migration after. This can be done by setting allow_structured_metadata: false at `.Values.loki.limits_config` in your values.yaml.

To perform the schema upgrade, a new schema version needs to be set in `.Values.loki.schemaConfig.configs` with the `from` date being a date in the future. For example, if you're performing the schema upgrade on 06-01-2024, a new schemaConfig entry for v13 may look like:

```yaml
        - from: "2024-06-02"
          index:
            period: 24h
            prefix: loki_tsdb_
          object_store: s3
          schema: v13
          store: tsdb
```

This ensures that logs on the same date won't be referenced by two different schema. Additional schema upgrade information can be found within Loki's documentation [here](https://grafana.com/docs/loki/latest/operations/storage/schema/#changing-the-schema).

By default, we have v13 schema `from` date set to 05-30-2024, which was the date of our release. If you plan on upgrading after that time, you will need to manually set the date yourselves for a date in the future.